# Sakurajima
Sakurajima is a Python 3 API wrapper for AniWatch.me and contains most endpoints.
## Usage
1. Install the package `pip install sakurajima`
2. Use it.
```python
from Sakurajima import Sakurajima
aniwatch = Sakurajima("username", "passsword")
```
